import 'package:flutter/cupertino.dart';

typedef LoadMoreListener = Function();

/// 预加载控制器，可应用于列表进行预加载功能
class PqPreLoader {
  /// 默认的触发与预加载的剩余滑动距离
  static const double DEFAULT_PRELOAD_DISTANCE_LIMIT = 1000;

  /// 滚动控制器
  final ScrollController scrollController;

  /// 加载更多的回调
  final LoadMoreListener loadMoreListener;

  /// 预加载高度
  final double preloadDistanceLimit;

  /// 记录上次的位置
  double _lastScrollPixels = 0;

  /// 构造方法，需要传入滚动控制器[ScrollController] `scrollController`和加载更多[loadMoreListener]的回调，
  /// 以及一个有预设值的距离[preloadDistanceLimit]
  PqPreLoader(
    this.scrollController, {
    this.preloadDistanceLimit = DEFAULT_PRELOAD_DISTANCE_LIMIT,
    required this.loadMoreListener,
  })  {
    scrollController.addListener(() {
      if (!scrollController.hasClients) return;

      double after = scrollController.position.extentAfter;
      double pixels = scrollController.position.pixels;

      /// 是向下滑动，且剩余可滑动距离低于设置的限制值
      if (pixels > 0 &&
          pixels > _lastScrollPixels &&
          after < preloadDistanceLimit) {
        loadMoreListener();
      }
      _lastScrollPixels = pixels;
    });
  }

}
