import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';
import 'package:pq_refresh/pq_refresh.dart';

/// * description: 基于Get中的SuperController进行二次封装，
/// 新增加了浮窗的能力（配合[YhPage]使用），控制键盘的能力
abstract class PqSuperController<M> extends SuperController<M> {
  /// 悬浮窗控制，需要页面和[YhPage]结合才可以使用
  /// 否则就需要自己去实现该逻辑
  var floatingWindow = false.obs;


  /// 隐藏键盘
  /// * node [FocusNode] 焦点，如果传入了就会使用 `unfocus()`方法
  /// * complete [Function] 关闭之后的回调
  void hideKeyboard({FocusNode? node, Function()? complete}) {
    if (node != null) {
      node.unfocus();
      complete?.call();
    } else {
      _keyboard('TextInput.hide', complete: complete);
    }
  }

  /// 显示键盘
  /// * node [FocusNode] 焦点，如果传入了就会使用 `requestFocus()`方法
  /// * complete [Function] 关闭之后的回调
  void showKeyboard({FocusNode? node, Function()? complete}) {
    if (node != null) {
      node.requestFocus();
      complete?.call();
    }else {
      _keyboard('TextInput.show', complete: complete);
    }
  }

  void _keyboard(String method, {Function()? complete}) {
    SystemChannels.textInput.invokeMethod(method).whenComplete(() {
      Future.delayed(Duration(milliseconds: 10))
          .whenComplete(() => complete?.call())
          .onError((error, stackTrace) {});
    }).onError((error, stackTrace) {});
  }
}
