import 'package:flutter/material.dart';

/// * description: 空数据视图
class PqStateEmptyView extends StatelessWidget {
  /// 构造方法
  /// * hint [String] 提示文本
  /// * asset [String] 图片
  /// * package [String] 图片包地址
  /// * padding [EdgeInsetsGeometry] 内容的边距
  /// * iconColor [String] 图片颜色
  /// * textColor [String] 文本颜色
  /// * bottomPadding [EdgeInsetsGeometry] 当传入了bottom的时候的边距
  /// * bottom [Widget] 底部自定义区域的控件
  const PqStateEmptyView({
    Key? key,
    this.hint,
    this.asset,
    this.package,
    this.padding,
    this.iconColor,
    this.textColor = const Color(0xFF999999),
    this.bottomPadding,
    this.bottom,
  }) : super(key: key);

  /// 提示文本
  final String? hint;

  /// 图片地址
  final String? asset;

  /// 图片地址
  final String? package;

  /// padding
  final EdgeInsetsGeometry? padding;

  /// 图片颜色
  final Color? iconColor;

  /// 文本颜色
  final Color textColor;

  /// bottom的padding，当传入了bottom的时候起作用
  final EdgeInsetsGeometry? bottomPadding;

  /// 底部控件，由外界自行定义
  final Widget? bottom;

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: padding ??
          EdgeInsets.only(bottom: MediaQuery.of(context).padding.bottom),
      alignment: Alignment.center,
      child: Center(
        child: _content(),
      ),
    );
  }

  _content() {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        if (asset?.isNotEmpty ?? false)
          Image.asset(asset!, package: package, color: iconColor),
        if (hint?.isNotEmpty ?? false)
          Text(hint!, style: TextStyle(color: textColor, fontSize: 15)),
        if (bottom != null)
          Padding(padding: bottomPadding ?? EdgeInsets.zero, child: bottom)
      ],
    );
  }
}
