import 'package:flutter/material.dart';

/// * description: 网络出错的视图
class PqStateNoNetworkView extends StatelessWidget {
  /// 构造方法
  /// * asset [String] 图片地址
  /// * package [String] 图片包名称
  /// * hint [String] 提示文案
  /// * btnText [String] 刷新按钮文案
  /// * onTap [Function] 点击事件
  /// * padding [EdgeInsetsGeometry] 边距
  /// * iconColor [Color] 图片颜色
  /// * textColor [Color] 文本颜色
  const PqStateNoNetworkView({
    Key? key,
    this.asset,
    this.package ,
    this.hint,
    this.btnText,
    this.onTap,
    this.padding = const EdgeInsets.all(0),
    this.iconColor,
    this.textColor = const Color(0xFF999999),
  });

  /// 图片地址
  final String? asset;

  /// 包名称
  final String? package;

  /// 提示文案
  final String? hint;

  /// 按钮文本
  final String? btnText;

  /// 点击事件
  final Function()? onTap;

  /// 边距
  final EdgeInsetsGeometry padding;

  /// 图片填充颜色
  final Color? iconColor;

  /// 文本颜色 默认是 `Color(0xFF999999)`
  final Color textColor;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        alignment: Alignment.center,
        child: Center(
          child: _content(context),
        ),
      ),
    );
  }

  _content(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        _image(),
        _text(),
        SizedBox(height: 20),
        _refreshBtn(),
        SizedBox(
          height: MediaQuery.of(context).padding.bottom,
        )
      ],
    );
  }

  _image() {
    if (asset?.isEmpty ?? true) return SizedBox.shrink();
    return Image.asset(
      asset!,
      package: package,
      fit: BoxFit.cover,
      color: iconColor,
    );
  }

  _text() {
    if (hint?.isEmpty ?? true) return SizedBox.shrink();

    return Text(hint!, style: TextStyle(color: textColor, fontSize: 13));
  }

  _refreshBtn() {
    if (btnText?.isEmpty ?? true) return SizedBox.shrink();

    return InkWell(
      onTap: onTap,
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(32),
          border: Border.all(color: Color(0xFF2A9F93), width: 0.5),
        ),
        padding: EdgeInsets.symmetric(horizontal: 20, vertical: 7),
        child: Text(
          btnText!,
          style: TextStyle(color: Color(0xFF2A9F93), fontSize: 14),
        ),
      ),
    );
  }
}
